@@ -461,6 +461,35 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDomainGroupList(self, request):
+        """获取域名分组列表
+
+        :param request: Request instance for DescribeDomainGroupList.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainGroupListRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainGroupListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDomainGroupList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDomainGroupListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDomainList(self, request):
         """获取域名列表
 
