@@ -1446,6 +1446,55 @@ class ServiceGovernanceInfo(AbstractModel):
         
 
 
+class UpdateEngineInternetAccessRequest(AbstractModel):
+    """UpdateEngineInternetAccess请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InstanceId: 引擎ID
+        :type InstanceId: str
+        :param EngineType: 引擎类型
+        :type EngineType: str
+        :param EnableClientInternetAccess: 是否开启客户端公网访问，true开 false关
+        :type EnableClientInternetAccess: bool
+        """
+        self.InstanceId = None
+        self.EngineType = None
+        self.EnableClientInternetAccess = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+        self.EngineType = params.get("EngineType")
+        self.EnableClientInternetAccess = params.get("EnableClientInternetAccess")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UpdateEngineInternetAccessResponse(AbstractModel):
+    """UpdateEngineInternetAccess返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class VpcInfo(AbstractModel):
     """私有网络信息
 
